##  Configuring Survey Permissions for Non-Admin Roles
By default, only admin users can create and manage surveys. However, admins can configure permissions to allow non-admins to manage surveys as well.
To configure survey permissions for a non-admin role, follow these steps:
  1. In the administration area, navigate to the User Roles and Permissions section.
  2. Select a non-admin role for which you want to configure permissions.
  3. On the role editing page, go to the Permissions tab.
  4. In the Surveys section, select the corresponding checkbox to allow this role to manage surveys.
  5. Save the changes.
![Configuring Survey Permissions for the Member Role](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2742381b7a4410148f82fb7d65aa0a98_LowRes.png)
Configuring Survey Permissions for the Member Role


**Tip**
  * To maintain control and quality over surveys, avoid granting survey permissions to large groups like the Member or Viewer roles.
  * Ensure that new users with survey creation permissions are proficient in all survey features, question framing, and effective email creation. Poorly managed surveys can result in excessive or irrelevant communications, potentially harming the perception of the SAP LeanIX tool in your organization and disrupting data collection from stakeholders


To learn more about permissions, see [Role-Based Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD#loio275def827a4410149362f3672c614956__role-based_permissions).
